==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/pt/lang.php <==
<?php
/**
 * Portugueselanguage file
 *
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 */
$lang['menu']                  = 'Gestor de Perfis';
$lang['noauth']                = '(autenticação indisponível)';
$lang['nosupport']             = '(gestão de utilizadores não suportada)';
$lang['badauth']               = 'Mecanismo de autenticação inválido';
$lang['user_id']               = 'Utilizador';
$lang['user_pass']             = 'Senha';
$lang['user_name']             = 'Nome Real';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Adicionar';
$lang['delete']                = 'Remover';
$lang['delete_selected']       = 'Remover Seleccionado(s)';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar utilizador';
$lang['modify']                = 'Gravar Alterações';
$lang['search']                = 'Pesquisar';
$lang['search_prompt']         = 'Pesquisar';
$lang['clear']                 = 'Limpar Filtro de Pesquisa';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Apresentar utilizadores %1$d-%2$d de %3$d encontrados. %4$d inscritos.';
$lang['nonefound']             = 'Nenhum utilizador encontrado. %d inscritos.';
$lang['delete_ok']             = '%d utilizadores removidos';
$lang['delete_fail']           = '%d remoções falhadas.';
$lang['update_ok']             = 'Utilizador actualizado';
$lang['update_fail']           = 'Utilizador não actualizado';
$lang['update_exists']         = 'Falhou a alteração do nome, porque o utilizador (%s) já existe (as restantes alterações serão aplicadas).';
$lang['start']                 = 'primeiro';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'seguinte';
$lang['last']                  = 'último';
$lang['edit_usermissing']      = 'Utilizador seleccionado não encontrado. Terá já sido removido ou alterado entretanto?';
$lang['user_notify']           = 'Notificar utilizador';
$lang['note_notify']           = 'Notificações só são enviadas se for atribuída uma nova senha ao utilizador.';
$lang['note_group']            = 'Os novos utilizadores são adicionados ao grupo por omissão (%s) se não for especificado nenhum grupo.';
$lang['add_ok']                = 'Utilizador adicionado.';
$lang['add_fail']              = 'Utilizador não adicionado.';
$lang['notify_ok']             = 'Mensagem de notificação enviada.';
$lang['notify_fail']           = 'Não foi possível enviar mensagem de notificação';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/pt/lang.php <==
<?php
/**
 * Portugueselanguage file
 *
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 */
$lang['menu']                  = 'Gestor de Perfis';
$lang['noauth']                = '(autenticação indisponível)';
$lang['nosupport']             = '(gestão de utilizadores não suportada)';
$lang['badauth']               = 'Mecanismo de autenticação inválido';
$lang['user_id']               = 'Utilizador';
$lang['user_pass']             = 'Senha';
$lang['user_name']             = 'Nome Real';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Adicionar';
$lang['delete']                = 'Remover';
$lang['delete_selected']       = 'Remover Seleccionado(s)';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar utilizador';
$lang['modify']                = 'Gravar Alterações';
$lang['search']                = 'Pesquisar';
$lang['search_prompt']         = 'Pesquisar';
$lang['clear']                 = 'Limpar Filtro de Pesquisa';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Apresentar utilizadores %1$d-%2$d de %3$d encontrados. %4$d inscritos.';
$lang['nonefound']             = 'Nenhum utilizador encontrado. %d inscritos.';
$lang['delete_ok']             = '%d utilizadores removidos';
$lang['delete_fail']           = '%d remoções falhadas.';
$lang['update_ok']             = 'Utilizador actualizado';
$lang['update_fail']           = 'Utilizador não actualizado';
$lang['update_exists']         = 'Falhou a alteração do nome, porque o utilizador (%s) já existe (as restantes alterações serão aplicadas).';
$lang['start']                 = 'primeiro';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'seguinte';
$lang['last']                  = 'último';
$lang['edit_usermissing']      = 'Utilizador seleccionado não encontrado. Terá já sido removido ou alterado entretanto?';
$lang['user_notify']           = 'Notificar utilizador';
$lang['note_notify']           = 'Notificações só são enviadas se for atribuída uma nova senha ao utilizador.';
$lang['note_group']            = 'Os novos utilizadores são adicionados ao grupo por omissão (%s) se não for especificado nenhum grupo.';
$lang['note_pass']             = 'A password será automáticamente gerada se o campo esquerdo estiver vazio e a notificação de utilizador estiver activada.';
$lang['add_ok']                = 'Utilizador adicionado.';
$lang['add_fail']              = 'Utilizador não adicionado.';
$lang['notify_ok']             = 'Mensagem de notificação enviada.';
$lang['notify_fail']           = 'Não foi possível enviar mensagem de notificação';
